@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -179,7 +179,7 @@ class DebugClientBase(object):
     clientCapabilities = DebugClientCapabilities.HasAll
     
     # keep these in sync with VariablesViewer.VariableItem.Indicators
-    Indicators = ("()", "[]", "{:}", "{}")         # __IGNORE_WARNING__
+    Indicators = ("()", "[]", "{:}", "{}")      # __IGNORE_WARNING_M613__
     
     def __init__(self):
         """
@@ -187,7 +187,6 @@ class DebugClientBase(object):
         """
         self.breakpoints = {}
         self.redirect = True
-        self.__receiveBuffer = ""
         
         # special objects representing the main scripts thread and frame
         self.mainThread = self
@@ -223,9 +222,6 @@ class DebugClientBase(object):
         
         self.variant = 'You should not see this'
         
-        # commandline completion stuff
-        self.complete = Completer(self.debugMod.__dict__).complete
-        
         self.compile_command = codeop.CommandCompiler()
         
         self.coding_re = re.compile(r"coding[:=]\s*([-\w_.]+)")
@@ -292,12 +288,12 @@ class DebugClientBase(object):
         """
         return eval(self.raw_input(prompt, True))
         
-    def sessionClose(self, exit=True):
+    def sessionClose(self, terminate=True):
         """
         Public method to close the session with the debugger and optionally
         terminate.
         
-        @param exit flag indicating to terminate (boolean)
+        @param terminate flag indicating to terminate (boolean)
         """
         try:
             self.set_quit()
@@ -313,7 +309,7 @@ class DebugClientBase(object):
         self.writestream.close(True)
         self.errorstream.close(True)
 
-        if exit:
+        if terminate:
             # Ok, go away.
             sys.exit()
 
@@ -358,23 +354,6 @@ class DebugClientBase(object):
         
         return code
     
-    def handleLine(self, line):
-        """
-        Public method to handle the receipt of a complete line.
-
-        It first looks for a valid protocol token at the start of the line.
-        Thereafter it trys to execute the lines accumulated so far.
-        
-        @param line the received line
-        """
-        # Remove any newline.
-        if line[-1] == '\n':
-            line = line[:-1]
-
-##        printerr(line)          ##debug
-        
-        self.handleJsonCommand(line)
-    
     def handleJsonCommand(self, jsonStr):
         """
         Public method to handle a command serialized as a JSON string.
@@ -382,9 +361,12 @@ class DebugClientBase(object):
         @param jsonStr string containing the command received from the IDE
         @type str
         """
+##        printerr(jsonStr)          ##debug
+        
         try:
             commandDict = json.loads(jsonStr.strip())
         except (TypeError, ValueError) as err:
+            printerr("Error handling command: " + jsonStr)
             printerr(str(err))
             return
         
@@ -396,12 +378,14 @@ class DebugClientBase(object):
         
         if method == "RequestVariables":
             self.__dumpVariables(
-                params["frameNumber"], params["scope"], params["filters"])
+                params["frameNumber"], params["scope"], params["filters"],
+                params["maxSize"])
         
         elif method == "RequestVariable":
             self.__dumpVariable(
                 params["variable"], params["frameNumber"],
-                params["scope"], params["filters"])
+                params["scope"], params["filters"],
+                params["maxSize"])
         
         elif method == "RequestThreadList":
             self.dumpThreadList()
@@ -726,6 +710,10 @@ class DebugClientBase(object):
                 self.set_quit()
                 self.eventExit = True
         
+        elif method == "RequestMoveIP":
+            newLine = params["newLine"]
+            self.currentThreadExec.move_instruction_pointer(newLine)
+        
         elif method == "RequestContinue":
             self.currentThreadExec.go(params["special"])
             self.eventExit = True
@@ -1026,25 +1014,24 @@ class DebugClientBase(object):
         Public method called when there is data ready to be read.
         
         @param stream file like object that has data to be written
+        @return flag indicating an error condition
+        @rtype bool
         """
+        error = False
+        
+        self.lockClient()
         try:
-            got = stream.readline_p()
+            command = stream.readCommand()
         except Exception:
-            return
+            error = True
+        self.unlockClient()
 
-        if len(got) == 0:
+        if len(command) == 0 or error:
             self.sessionClose()
-            return
-
-        self.__receiveBuffer = self.__receiveBuffer + got
-
-        # Call handleLine for the line if it is complete.
-        eol = self.__receiveBuffer.find('\n')
-        while eol >= 0:
-            line = self.__receiveBuffer[:eol + 1]
-            self.__receiveBuffer = self.__receiveBuffer[eol + 1:]
-            self.handleLine(line)
-            eol = self.__receiveBuffer.find('\n')
+        else:
+            self.handleJsonCommand(command)
+        
+        return error
 
     def writeReady(self, stream):
         """
@@ -1097,7 +1084,9 @@ class DebugClientBase(object):
                 continue
 
             if self.readstream in rrdy:
-                self.readReady(self.readstream)
+                error = self.readReady(self.readstream)
+                if error:
+                    break
 
             if self.writestream in wrdy:
                 self.writeReady(self.writestream)
@@ -1320,15 +1309,20 @@ class DebugClientBase(object):
         # reset coding
         self.__coding = self.defaultCoding
 
-    def __dumpVariables(self, frmnr, scope, filter):
+    def __dumpVariables(self, frmnr, scope, filterList, maxSize):
         """
         Private method to return the variables of a frame to the debug server.
         
         @param frmnr distance of frame reported on. 0 is the current frame
-            (int)
-        @param scope 1 to report global variables, 0 for local variables (int)
-        @param filter the indices of variable types to be filtered
-            (list of int)
+        @type int
+        @param scope 1 to report global variables, 0 for local variables
+        @type int
+        @param filterList the indices of variable types to be filtered
+        @type list of int
+        @param maxSize maximum size the formatted value of a variable will
+            be shown. If it is bigger than that, a 'too big' indication will
+            be given.
+        @type int
         """
         if self.currentThread is None:
             return
@@ -1345,22 +1339,23 @@ class DebugClientBase(object):
         
         if f is None:
             if scope:
-                dict = self.debugMod.__dict__
+                varDict = self.debugMod.__dict__
             else:
                 scope = -1
         elif scope:
-            dict = f.f_globals
+            varDict = f.f_globals
         elif f.f_globals is f.f_locals:
                 scope = -1
         else:
-            dict = f.f_locals
+            varDict = f.f_locals
             
         varlist = []
         
         if scope != -1:
-            keylist = dict.keys()
+            keylist = varDict.keys()
             
-            vlist = self.__formatVariablesList(keylist, dict, scope, filter)
+            vlist = self.__formatVariablesList(
+                keylist, varDict, scope, filterList, maxSize=maxSize)
             varlist.extend(vlist)
         
         self.sendJsonCommand("ResponseVariables", {
@@ -1368,17 +1363,21 @@ class DebugClientBase(object):
             "variables": varlist,
         })
     
-    def __dumpVariable(self, var, frmnr, scope, filter):
+    def __dumpVariable(self, var, frmnr, scope, filterList, maxSize):
         """
         Private method to return the variables of a frame to the debug server.
         
         @param var list encoded name of the requested variable
-            (list of strings)
+        @type list of strings
         @param frmnr distance of frame reported on. 0 is the current frame
-            (int)
+        @type int
         @param scope 1 to report global variables, 0 for local variables (int)
-        @param filter the indices of variable types to be filtered
-            (list of int)
+        @param filterList the indices of variable types to be filtered
+        @type list of int
+        @param maxSize maximum size the formatted value of a variable will
+            be shown. If it is bigger than that, a 'too big' indication will
+            be given.
+        @type int
         """
         if self.currentThread is None:
             return
@@ -1392,20 +1391,20 @@ class DebugClientBase(object):
         
         if f is None:
             if scope:
-                dict = self.debugMod.__dict__
+                varDict = self.debugMod.__dict__
             else:
                 scope = -1
         elif scope:
-            dict = f.f_globals
+            varDict = f.f_globals
         elif f.f_globals is f.f_locals:
                 scope = -1
         else:
-            dict = f.f_locals
+            varDict = f.f_locals
         
         varlist = []
         
         if scope != -1:
-            variable = dict
+            variable = varDict
             for attribute in var:
                 attribute = self.__extractIndicators(attribute)[0]
                 typeObject, typeName, typeStr, resolver = \
@@ -1425,9 +1424,10 @@ class DebugClientBase(object):
                     vlist = self.__formatQtVariable(variable, typeName)
                     varlist.extend(vlist)
                 elif resolver:
-                    dict = resolver.getDictionary(variable)
+                    varDict = resolver.getDictionary(variable)
                     vlist = self.__formatVariablesList(
-                        list(dict.keys()), dict, scope, filter)
+                        list(varDict.keys()), varDict, scope, filterList,
+                        maxSize=maxSize)
                     varlist.extend(vlist)
         
         self.sendJsonCommand("ResponseVariable", {
@@ -1597,8 +1597,8 @@ class DebugClientBase(object):
             
         return varlist
     
-    def __formatVariablesList(self, keylist, dict_, scope, filter=[],
-                              formatSequences=False):
+    def __formatVariablesList(self, keylist, dict_, scope, filterList=None,
+                              formatSequences=False, maxSize=0):
         """
         Private method to produce a formated variables list.
         
@@ -1608,22 +1608,34 @@ class DebugClientBase(object):
         expressions. The formated variables list (a list of tuples of 3
         values) is returned.
         
-        @param keylist keys of the dictionary
+        @param keylist keys of the dictionary to be formatted
+        @type list of str
         @param dict_ the dictionary to be scanned
+        @type dict
         @param scope 1 to filter using the globals filter, 0 using the locals
-            filter (int).
+            filter.
             Variables are only added to the list, if their name do not match
             any of the filter expressions.
-        @param filter the indices of variable types to be filtered. Variables
-            are only added to the list, if their type is not contained in the
-            filter list.
+        @type int
+        @param filterList the indices of variable types to be filtered.
+            Variables are only added to the list, if their type is not
+            contained in the filter list.
+        @type list of int
         @param formatSequences flag indicating, that sequence or dictionary
             variables should be formatted. If it is 0 (or false), just the
-            number of items contained in these variables is returned. (boolean)
+            number of items contained in these variables is returned.
+        @type bool
+        @param maxSize maximum size the formatted value of a variable will
+            be shown. If it is bigger than that, a 'too big' indication will
+            be placed in the value field.
+        @type int
         @return A tuple consisting of a list of formatted variables. Each
             variable entry is a tuple of three elements, the variable name,
             its type and value.
+        @rtype list of tuple of (str, str, str)
         """
+        filterList = [] if filterList is None else filterList[:]
+        
         varlist = []
         if scope:
             patternFilterObjects = self.globalsFilterObjects
@@ -1641,7 +1653,7 @@ class DebugClientBase(object):
                 continue
             
             # filter hidden attributes (filter #0)
-            if 0 in filter and str(key)[:2] == '__' and not (
+            if 0 in filterList and str(key)[:2] == '__' and not (
                 key == "___len___" and
                     DebugVariables.TooLargeAttribute in keylist):
                 continue
@@ -1658,19 +1670,19 @@ class DebugClientBase(object):
                 valtypename = type(value).__name__
                 if valtype not in ConfigVarTypeStrings:
                     if valtype in ["numpy.ndarray", "array.array"]:
-                        if ConfigVarTypeStrings.index('list') in filter:
+                        if ConfigVarTypeStrings.index('list') in filterList:
                             continue
                     elif valtypename == "MultiValueDict":
-                        if ConfigVarTypeStrings.index('dict') in filter:
+                        if ConfigVarTypeStrings.index('dict') in filterList:
                             continue
                     elif valtype == "sip.methoddescriptor":
                         if ConfigVarTypeStrings.index(
-                                'method') in filter:
+                                'method') in filterList:
                             continue
                     elif valtype == "sip.enumtype":
-                        if ConfigVarTypeStrings.index('class') in filter:
+                        if ConfigVarTypeStrings.index('class') in filterList:
                             continue
-                    elif ConfigVarTypeStrings.index('instance') in filter:
+                    elif ConfigVarTypeStrings.index('instance') in filterList:
                         continue
                     
                     if (not valtypestr.startswith('type ') and
@@ -1683,22 +1695,24 @@ class DebugClientBase(object):
                         if valtype == "instancemethod":
                             valtype = "method"
                         
-                        if ConfigVarTypeStrings.index(valtype) in filter:
+                        if ConfigVarTypeStrings.index(valtype) in filterList:
                             continue
                     except ValueError:
                         if valtype == "classobj":
                             if ConfigVarTypeStrings.index(
-                                    'instance') in filter:
+                                    'instance') in filterList:
                                 continue
                         elif valtype == "sip.methoddescriptor":
                             if ConfigVarTypeStrings.index(
-                                    'method') in filter:
+                                    'method') in filterList:
                                 continue
                         elif valtype == "sip.enumtype":
-                            if ConfigVarTypeStrings.index('class') in filter:
+                            if ConfigVarTypeStrings.index('class') in \
+                                    filterList:
                                 continue
                         elif not valtype.startswith("PySide") and \
-                                ConfigVarTypeStrings.index('other') in filter:
+                            (ConfigVarTypeStrings.index('other') in
+                             filterList):
                             continue
                 
                 try:
@@ -1718,6 +1732,8 @@ class DebugClientBase(object):
                         if valtype.startswith('class') and \
                            rvalue[0] in ['{', '(', '[']:
                             rvalue = ""
+                        elif maxSize and len(rvalue) > maxSize:
+                            rvalue = "@@TOO_BIG_TO_SHOW@@"
                 except Exception:
                     rvalue = ''
             
@@ -1773,7 +1789,20 @@ class DebugClientBase(object):
             self.__getCompletionList(text, localCompleter, completions)
         except AttributeError:
             pass
-        self.__getCompletionList(text, self.complete, completions)
+        
+        cf = self.currentThread.getCurrentFrame()
+        frmnr = self.framenr
+        while cf is not None and frmnr > 0:
+            cf = cf.f_back
+            frmnr -= 1
+        
+        if cf is None:
+            globaldict = self.debugMod.__dict__
+        else:
+            globaldict = cf.f_globals
+        
+        globalCompleter = Completer(globaldict).complete
+        self.__getCompletionList(text, globalCompleter, completions)
         
         self.sendJsonCommand("ResponseCompletion", {
             "completions": list(completions),
@@ -2002,7 +2031,8 @@ class DebugClientBase(object):
                 else:   # unknown option
                     del args[0]
             if not args:
-                print("No program given. Aborting!")    # __IGNORE_WARNING__
+                print("No program given. Aborting!")
+                # __IGNORE_WARNING_M801__
             else:
                 if not self.noencoding:
                     self.__coding = self.defaultCoding
@@ -2014,16 +2044,25 @@ class DebugClientBase(object):
             if sys.argv[1] == '--no-encoding':
                 self.noencoding = True
                 del sys.argv[1]
+            
             if sys.argv[1] == '':
                 del sys.argv[1]
+            
             try:
                 port = int(sys.argv[1])
             except (ValueError, IndexError):
                 port = -1
-            try:
-                redirect = int(sys.argv[2])
-            except (ValueError, IndexError):
+            
+            if sys.argv[2] == "True":
                 redirect = True
+            elif sys.argv[2] == "False":
+                redirect = False
+            else:
+                try:
+                    redirect = int(sys.argv[2])
+                except (ValueError, IndexError):
+                    redirect = True
+            
             try:
                 ipOrHost = sys.argv[3]
                 if ':' in ipOrHost:
@@ -2034,16 +2073,19 @@ class DebugClientBase(object):
                     remoteAddress = self.__resolveHost(ipOrHost)
             except Exception:
                 remoteAddress = None
+            
             sys.argv = ['']
             if '' not in sys.path:
                 sys.path.insert(0, '')
+            
             if port >= 0:
                 if not self.noencoding:
                     self.__coding = self.defaultCoding
                 self.connectDebugger(port, remoteAddress, redirect)
                 self.__interact()
             else:
-                print("No network port given. Aborting...")     # __IGNORE_WARNING__
+                print("No network port given. Aborting...")
+                # __IGNORE_WARNING_M801__
         
     def fork(self):
         """
@@ -2061,13 +2103,13 @@ class DebugClientBase(object):
             if not self.fork_child:
                 sys.settrace(None)
                 sys.setprofile(None)
-                self.sessionClose(0)
+                self.sessionClose(False)
         else:
             # parent
             if self.fork_child:
                 sys.settrace(None)
                 sys.setprofile(None)
-                self.sessionClose(0)
+                self.sessionClose(False)
         return pid
         
     def close(self, fd):
