@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,9 +9,8 @@ Module implementing a specialized error message dialog.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import qInstallMessageHandler, QCoreApplication, \
-    QtDebugMsg, QtWarningMsg, QtCriticalMsg, QtFatalMsg, QThread, \
-    QMetaObject, Qt, Q_ARG, QSettings
+from PyQt5.QtCore import qInstallMessageHandler, QtDebugMsg, QtWarningMsg, \
+    QtCriticalMsg, QtFatalMsg, QThread, QMetaObject, Qt, Q_ARG, QSettings
 from PyQt5.QtWidgets import QErrorMessage, qApp, QDialog
 
 import Globals
@@ -47,6 +46,10 @@ class E5ErrorMessage(QErrorMessage):
             ",type id:",
             "Remote debugging server started successfully",
             "Uncaught SecurityError:",
+            "Content Security Policy",
+            "QXcbClipboard:",
+            "QXcbConnection: XCB error",
+            "libpng warning: iCCP:",
         ]
     
     def __filterMessage(self, message):
@@ -57,9 +60,9 @@ class E5ErrorMessage(QErrorMessage):
         @return flag indicating that the message should be filtered out
             (boolean)
         """
-        for filter in Globals.toList(self.settings.value(
+        for filterStr in Globals.toList(self.settings.value(
                 "MessageFilters", self.__defaultFilters)):
-            if filter in message:
+            if filterStr in message:
                 return True
         
         return False
@@ -84,7 +87,8 @@ class E5ErrorMessage(QErrorMessage):
         from .E5ErrorMessageFilterDialog import E5ErrorMessageFilterDialog
         dlg = E5ErrorMessageFilterDialog(
             Globals.toList(self.settings.value(
-                "MessageFilters", self.__defaultFilters)))
+                "MessageFilters", self.__defaultFilters)),
+            self.__defaultFilters)
         if dlg.exec_() == QDialog.Accepted:
             filters = dlg.getFilters()
             self.settings.setValue("MessageFilters", filters)
@@ -107,17 +111,13 @@ def messageHandler(msgType, *args):
     if __msgHandlerDialog:
         try:
             if msgType == QtDebugMsg:
-                messageType = QCoreApplication.translate(
-                    "E5ErrorMessage", "Debug Message:")
+                messageType = "Debug Message:"
             elif msgType == QtWarningMsg:
-                messageType = QCoreApplication.translate(
-                    "E5ErrorMessage", "Warning:")
+                messageType = "Warning:"
             elif msgType == QtCriticalMsg:
-                messageType = QCoreApplication.translate(
-                    "E5ErrorMessage", "Critical:")
+                messageType = "Critical:"
             elif msgType == QtFatalMsg:
-                messageType = QCoreApplication.translate(
-                    "E5ErrorMessage", "Fatal Error:")
+                messageType = "Fatal Error:"
             if isinstance(message, bytes):
                 message = Utilities.decodeBytes(message)
             message = message.replace("\r\n", "<br/>")\
@@ -147,17 +147,13 @@ def messageHandler(msgType, *args):
         return
     
     if msgType == QtDebugMsg:
-        messageType = QCoreApplication.translate(
-            "E5ErrorMessage", "Debug Message")
+        messageType = "Debug Message"
     elif msgType == QtWarningMsg:
-        messageType = QCoreApplication.translate(
-            "E5ErrorMessage", "Warning")
+        messageType = "Warning"
     elif msgType == QtCriticalMsg:
-        messageType = QCoreApplication.translate(
-            "E5ErrorMessage", "Critical")
+        messageType = "Critical"
     elif msgType == QtFatalMsg:
-        messageType = QCoreApplication.translate(
-            "E5ErrorMessage", "Fatal Error")
+        messageType = "Fatal Error"
     if isinstance(message, bytes):
         message = message.decode()
     if len(args) == 2:
@@ -192,8 +188,7 @@ def editMessageFilters():
     if __msgHandlerDialog:
         __msgHandlerDialog.editMessageFilters()
     else:
-        print(QCoreApplication.translate(
-            "E5ErrorMessage", "No message handler installed."))
+        print("No message handler installed.")
 
 
 def messageHandlerInstalled():
