@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,13 +10,14 @@ Module implementing a sidebar class.
 from __future__ import unicode_literals
 
 from PyQt5.QtCore import QEvent, QSize, Qt, QByteArray, QDataStream, \
-    QIODevice, QTimer, qVersion
+    QIODevice, QTimer
 from PyQt5.QtWidgets import QTabBar, QWidget, QStackedWidget, QBoxLayout, \
     QToolButton, QSizePolicy
 
 from E5Gui.E5Application import e5App
 
 import UI.PixmapCache
+from Globals import qVersionTuple
 
 
 class E5SideBar(QWidget):
@@ -254,7 +255,7 @@ class E5SideBar(QWidget):
                 elif self.isMinimized():
                     self.expand()
             elif evt.type() == QEvent.Wheel:
-                if qVersion() >= "5.0.0":
+                if qVersionTuple() >= (5, 0, 0):
                     delta = evt.angleDelta().y()
                 else:
                     delta = evt.delta()
