@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,7 +10,7 @@ Module implementing a subclass of E5GraphicsView for our diagrams.
 from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSignal, Qt, QSignalMapper, QFileInfo, QEvent, \
-    QRectF, qVersion
+    QRectF
 from PyQt5.QtWidgets import QGraphicsView, QAction, QToolBar, QDialog
 from PyQt5.QtPrintSupport import QPrinter, QPrintDialog
 
@@ -25,6 +25,7 @@ import UI.Config
 import UI.PixmapCache
 
 import Preferences
+from Globals import qVersionTuple
 
 
 class UMLGraphicsView(E5GraphicsView):
@@ -601,7 +602,7 @@ class UMLGraphicsView(E5GraphicsView):
         @param evt reference to the wheel event (QWheelEvent)
         """
         if evt.modifiers() & Qt.ControlModifier:
-            if qVersion() >= "5.0.0":
+            if qVersionTuple() >= (5, 0, 0):
                 delta = evt.angleDelta().y()
             else:
                 delta = evt.delta()
