@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -25,6 +25,8 @@ class AdBlockManager(QObject):
     Class implementing the AdBlock manager.
     
     @signal rulesChanged() emitted after some rule has changed
+    @signal requiredSubscriptionLoaded(subscription) emitted to indicate
+        loading of a required subscription is finished (AdBlockSubscription)
     """
     rulesChanged = pyqtSignal()
     requiredSubscriptionLoaded = pyqtSignal(AdBlockSubscription)
