@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 
@@ -18,7 +18,7 @@ import os
 
 from PyQt5.QtCore import pyqtSlot, pyqtSignal, QObject, QT_TRANSLATE_NOOP, \
     QUrl, QBuffer, QIODevice, QFileInfo, Qt, QTimer, QEvent, \
-    QRect, QFile, QPoint, QByteArray, qVersion
+    QRect, QFile, QPoint, QByteArray
 from PyQt5.QtGui import QDesktopServices, QClipboard, QMouseEvent, QColor, \
     QPalette
 from PyQt5.QtWidgets import qApp, QStyle, QMenu, QApplication, QInputDialog, \
@@ -40,6 +40,7 @@ import Helpviewer
 import Preferences
 import UI.PixmapCache
 import Globals
+from Globals import qVersionTuple
 import Utilities
 
 try:
@@ -601,7 +602,7 @@ class HelpWebPage(QWebPage):
                 if cert in localCAList:
                     return True
         
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             for cert in certList:
                 if cert.isBlacklisted():
                     return False
@@ -1655,7 +1656,7 @@ class HelpBrowser(QWebView):
 ##        if searchUrl.scheme() != "http":
 ##            return
         
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             from PyQt5.QtCore import QUrlQuery
             searchUrlQuery = QUrlQuery(searchUrl)
         searchEngines = {}
@@ -1670,18 +1671,18 @@ class HelpBrowser(QWebView):
             elif type_ == "text":
                 if inputField == element:
                     value = "{searchTerms}"
-                if qVersion() >= "5.0.0":
+                if qVersionTuple() >= (5, 0, 0):
                     searchUrlQuery.addQueryItem(name, value)
                 else:
                     searchUrl.addQueryItem(name, value)
             elif type_ == "checkbox" or type_ == "radio":
                 if inputField.evaluateJavaScript("this.checked"):
-                    if qVersion() >= "5.0.0":
+                    if qVersionTuple() >= (5, 0, 0):
                         searchUrlQuery.addQueryItem(name, value)
                     else:
                         searchUrl.addQueryItem(name, value)
             elif type_ == "hidden":
-                if qVersion() >= "5.0.0":
+                if qVersionTuple() >= (5, 0, 0):
                     searchUrlQuery.addQueryItem(name, value)
                 else:
                     searchUrl.addQueryItem(name, value)
@@ -1696,7 +1697,7 @@ class HelpBrowser(QWebView):
             
             options = selectField.findAll("option")
             value = options.at(selectedIndex).toPlainText()
-            if qVersion() >= "5.0.0":
+            if qVersionTuple() >= (5, 0, 0):
                 searchUrlQuery.addQueryItem(name, value)
             else:
                 searchUrl.addQueryItem(name, value)
@@ -1713,7 +1714,7 @@ class HelpBrowser(QWebView):
                 return
             
             if searchEngines[searchEngine] != "":
-                if qVersion() >= "5.0.0":
+                if qVersionTuple() >= (5, 0, 0):
                     searchUrlQuery.addQueryItem(
                         searchEngines[searchEngine], searchEngine)
                 else:
@@ -1733,14 +1734,14 @@ class HelpBrowser(QWebView):
         if not ok:
             return
         
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             searchUrl.setQuery(searchUrlQuery)
         
         from .OpenSearch.OpenSearchEngine import OpenSearchEngine
         engine = OpenSearchEngine()
         engine.setName(engineName)
         engine.setDescription(engineName)
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             engine.setSearchUrlTemplate(
                 searchUrl.toDisplayString(QUrl.FullyDecoded))
         else:
@@ -1872,7 +1873,7 @@ class HelpBrowser(QWebView):
         
         @param evt reference to the wheel event (QWheelEvent)
         """
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             delta = evt.angleDelta().y()
         else:
             delta = evt.delta()
