@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,7 +12,7 @@ from __future__ import unicode_literals
 import os
 
 from PyQt5.QtCore import pyqtSignal, Qt, QSize, QSignalMapper, QFileInfo, \
-    QFile, QEvent, qVersion
+    QFile, QEvent
 from PyQt5.QtGui import QPalette, QImage, QImageReader, QImageWriter, \
     QKeySequence
 from PyQt5.QtWidgets import QScrollArea, QLabel, QDockWidget, QWhatsThis
@@ -28,6 +28,7 @@ import UI.PixmapCache
 import UI.Config
 
 import Preferences
+from Globals import qVersionTuple
 
 
 class IconEditorWindow(E5MainWindow):
@@ -1352,7 +1353,7 @@ class IconEditorWindow(E5MainWindow):
         @param evt reference to the wheel event (QWheelEvent)
         """
         if evt.modifiers() & Qt.ControlModifier:
-            if qVersion() >= "5.0.0":
+            if qVersionTuple() >= (5, 0, 0):
                 delta = evt.angleDelta().y()
             else:
                 delta = evt.delta()
@@ -1387,8 +1388,9 @@ class IconEditorWindow(E5MainWindow):
         pinch = evt.gesture(Qt.PinchGesture)
         if pinch:
             if pinch.state() == Qt.GestureStarted:
-                pinch.setScaleFactor(self.__editor.zoomFactor() / 100.0)
-            else:
-                self.__editor.setZoomFactor(int(pinch.scaleFactor() * 100))
+                pinch.setTotalScaleFactor(self.__editor.zoomFactor() / 100.0)
+            elif pinch.state() == Qt.GestureUpdated:
+                self.__editor.setZoomFactor(
+                    int(pinch.totalScaleFactor() * 100))
                 self.__updateZoom()
             evt.accept()
