@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -304,23 +304,24 @@ class PluginManager(QObject):
             if self.isValidPluginName(develPluginName):
                 develPluginName = develPluginName[:-3]
         
-        for pluginName in self.__foundCoreModules:
-            # global and user plugins have priority
-            if pluginName not in self.__foundGlobalModules and \
-               pluginName not in self.__foundUserModules and \
-               pluginName != develPluginName:
-                self.loadPlugin(pluginName, self.pluginDirs["eric6"])
-        
         for pluginName in self.__foundGlobalModules:
-            # user plugins have priority
+            # user and core plug-ins have priority
             if pluginName not in self.__foundUserModules and \
+               pluginName not in self.__foundCoreModules and \
                pluginName != develPluginName:
                 self.loadPlugin(pluginName, self.pluginDirs["global"])
         
         for pluginName in self.__foundUserModules:
-            if pluginName != develPluginName:
+            # core plug-ins have priority
+            if pluginName not in self.__foundCoreModules and \
+               pluginName != develPluginName:
                 self.loadPlugin(pluginName, self.pluginDirs["user"])
         
+        for pluginName in self.__foundCoreModules:
+            # plug-in under development has priority
+            if pluginName != develPluginName:
+                self.loadPlugin(pluginName, self.pluginDirs["eric6"])
+        
         if develPluginName:
             self.loadPlugin(develPluginName, develPluginPath)
             self.__develPluginName = develPluginName
@@ -1324,7 +1325,6 @@ class PluginManager(QObject):
             if getattr(module, "pluginType", "") == type_:
                 if hasattr(module, "clearPrivateData"):
                     module.clearPrivateData()
-        # TODO: document this in the plug-ins paper
 
 #
 # eflag: noqa = M801
