@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 
@@ -14,6 +14,7 @@ import sys
 import os
 import zipfile
 import glob
+import re
 
 from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt, QFile, QIODevice, QUrl, \
     QProcess, QPoint, QCoreApplication
@@ -334,7 +335,7 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         self.__installButton.setEnabled(False)
         for itm in self.repositoryList.selectedItems():
             if itm not in [self.__stableItem, self.__unstableItem,
-                           self.__unknownItem]:
+                           self.__unknownItem, self.__obsoleteItem]:
                 url = itm.data(0, PluginRepositoryWidget.UrlRole)
                 filename = os.path.join(
                     Preferences.getPluginManager("DownloadPath"),
@@ -389,6 +390,7 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         self.__stableItem = None
         self.__unstableItem = None
         self.__unknownItem = None
+        self.__obsoleteItem = None
         
         self.__newItems = 0
         self.__updateLocalItems = 0
@@ -591,6 +593,13 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
                                     [self.tr("Unstable")])
                 self.__unstableItem.setExpanded(True)
             parent = self.__unstableItem
+        elif status == "obsolete":
+            if self.__obsoleteItem is None:
+                self.__obsoleteItem = \
+                    QTreeWidgetItem(self.repositoryList,
+                                    [self.tr("Obsolete")])
+                self.__obsoleteItem.setExpanded(True)
+            parent = self.__obsoleteItem
         else:
             if self.__unknownItem is None:
                 self.__unknownItem = \
@@ -877,22 +886,31 @@ def PluginRepositoryDownloadCleanup(quiet=False):
         if not os.path.isfile(os.path.join(downloadPath, pluginFile)):
             continue
         
-        pluginName = pluginFile.rsplit("-", 1)[0]
+        pluginName, pluginVersion = \
+            pluginFile.replace(".zip", "").rsplit("-", 1)
+        pluginVersionList = re.split("[._-]", pluginVersion)
+        for index in range(len(pluginVersionList)):
+            try:
+                pluginVersionList[index] = int(pluginVersionList[index])
+            except ValueError:
+                # use default of 0
+                pluginVersionList[index] = 0
+        
         if pluginName not in downloads:
             downloads[pluginName] = []
-        downloads[pluginName].append(pluginFile)
+        downloads[pluginName].append((pluginFile, tuple(pluginVersionList)))
     
     # step 2: delete old entries
     hiddenPlugins = Preferences.getPluginManager("HiddenPlugins")
     for pluginName in downloads:
-        downloads[pluginName].sort()
+        downloads[pluginName].sort(key=lambda x: x[1])
     
         if pluginName in hiddenPlugins and \
                 not Preferences.getPluginManager("KeepHidden"):
-            removeFiles = downloads[pluginName]
+            removeFiles = [f[0] for f in downloads[pluginName]]
         else:
-            removeFiles = downloads[pluginName][
-                :-Preferences.getPluginManager("KeepGenerations")]
+            removeFiles = [f[0] for f in downloads[pluginName][
+                :-Preferences.getPluginManager("KeepGenerations")]]
         for removeFile in removeFiles:
             try:
                 os.remove(os.path.join(downloadPath, removeFile))
