@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -15,6 +15,7 @@ except NameError:
 
 import os
 import re
+import sys
 
 from PyQt5.QtCore import pyqtSlot, Qt, QProcess
 from PyQt5.QtGui import QCursor
@@ -143,7 +144,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         # 2.1b. Forms Compiler PyQt4
         self.__createProgramEntry(
             self.tr("Forms Compiler (Python, PyQt4)"),
-            Utilities.generatePyQtToolPath("pyuic4"),
+            Utilities.generatePyQtToolPath("pyuic4", ["py3uic4", "py2uic4"]),
             '--version', 'Python User', 4)
         # 2.1c. Resource Compiler PyQt4
         self.__createProgramEntry(
@@ -160,7 +161,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         # 2.2b. Forms Compiler PyQt5
         self.__createProgramEntry(
             self.tr("Forms Compiler (Python, PyQt5)"),
-            Utilities.generatePyQtToolPath("pyuic5"),
+            Utilities.generatePyQtToolPath("pyuic5", ["py3uic5", "py2uic5"]),
             '--version', 'Python User', 4)
         # 2.2c. Resource Compiler PyQt5
         self.__createProgramEntry(
@@ -197,13 +198,30 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
             Utilities.isWindowsPlatform() and "rbrcc.exe" or "rbrcc",
             '-version', 'Ruby Resource Compiler', -1)
         
-        # 5. do the CORBA programs
+        # 5. do the CORBA and Protobuf programs
         # 5a. omniORB
         exe = Preferences.getCorba("omniidl")
+        if not exe:
+            exe = "omniidl"
         if Utilities.isWindowsPlatform():
             exe += ".exe"
         self.__createProgramEntry(
             self.tr("CORBA IDL Compiler"), exe, '-V', 'omniidl', -1)
+        # 5b. protobuf
+        exe = Preferences.getProtobuf("protoc")
+        if not exe:
+            exe = "protoc"
+        if Utilities.isWindowsPlatform():
+            exe += ".exe"
+        self.__createProgramEntry(
+            self.tr("Protobuf Compiler"), exe, '--version', 'libprotoc', -1)
+        # 5c. grpc
+        exe = Preferences.getProtobuf("grpcPython")
+        if not exe:
+            exe = sys.executable
+        self.__createProgramEntry(
+            self.tr("gRPC Compiler"), exe, '--version', 'libprotoc', -1,
+            exeModule=['-m', 'grpc_tools.protoc'])
         
         # 6. do the spell checking entry
         try:
@@ -243,6 +261,8 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         pm = e5App().getObject("PluginManager")
         for info in pm.getPluginExeDisplayData():
             if info["programEntry"]:
+                if "exeModule" not in info:
+                    info["exeModule"] = None
                 self.__createProgramEntry(
                     info["header"],
                     info["exe"],
@@ -251,6 +271,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                     versionPosition=info["versionPosition"],
                     version=info["version"],
                     versionCleanup=info["versionCleanup"],
+                    exeModule=info["exeModule"],
                 )
             else:
                 self.__createEntry(
@@ -267,14 +288,15 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
     def __createProgramEntry(self, description, exe,
                              versionCommand="", versionStartsWith="",
                              versionPosition=0, version="",
-                             versionCleanup=None, versionRe=None):
+                             versionCleanup=None, versionRe=None,
+                             exeModule=None):
         """
         Private method to generate a program entry.
         
         @param description descriptive text (string)
         @param exe name of the executable program (string)
         @param versionCommand command line switch to get the version info
-            (string) if this is empty, the given version will be shown.
+            (str). If this is empty, the given version will be shown.
         @param versionStartsWith start of line identifying version info
             (string)
         @param versionPosition index of part containing the version info
@@ -284,6 +306,9 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
             start and stop for the version string (tuple of integers)
         @keyparam versionRe regexp to determine the line identifying version
             info (string). Takes precedence over versionStartsWith.
+        @keyparam exeModule list of command line parameters to execute a module
+            with the program given in exe (e.g. to execute a Python module)
+            (list of str)
         @return version string of detected or given version (string)
         """
         itmList = self.programsList.findItems(
@@ -310,7 +335,11 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                    versionPosition:
                     proc = QProcess()
                     proc.setProcessChannelMode(QProcess.MergedChannels)
-                    proc.start(exe, [versionCommand])
+                    if exeModule:
+                        args = exeModule[:] + [versionCommand]
+                    else:
+                        args = [versionCommand]
+                    proc.start(exe, args)
                     finished = proc.waitForFinished(10000)
                     if finished:
                         output = str(proc.readAllStandardOutput(),
@@ -335,7 +364,12 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                             version = self.tr("(unknown)")
                     else:
                         version = self.tr("(not executable)")
-                QTreeWidgetItem(itm, [exe, version])
+                if exeModule:
+                    QTreeWidgetItem(itm, [
+                        "{0} {1}".format(exe, " ".join(exeModule)),
+                        version])
+                else:
+                    QTreeWidgetItem(itm, [exe, version])
                 itm.setExpanded(True)
             else:
                 itm.setText(1, self.tr("(not found)"))
