@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -39,17 +39,10 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
     """
     A class used to display the translations part of the project.
     
-    @signal linguistFile(str) emitted to open a translation file with
-        Qt-Linguist
     @signal appendStdout(str) emitted after something was received from
         a QProcess on stdout
     @signal appendStderr(str) emitted after something was received from
         a QProcess on stderr
-    @signal sourceFile(str) emitted to open a translation file in an editor
-    @signal closeSourceWindow(str) emitted after a file has been
-        removed/deleted from the project
-    @signal trpreview(list of str, bool = False) emitted to preview
-        translations in the translations previewer
     @signal showMenu(str, QMenu) emitted when a menu is about to be shown.
         The name of the menu and a reference to the menu are given.
     """
@@ -818,20 +811,10 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 for key, fileList in sections:
                     if len(fileList) > 0:
                         pf.write('{0} = '.format(key))
-                        last = len(fileList) - 1
-                        if last > 0:
-                            pf.write('{0} \\{1}'.format(
-                                fileList[0].replace(os.sep, '/'), "\n"))
-                            for i in range(1, last):
-                                pf.write('\t{0} \\{1}'.format(
-                                    fileList[i].replace(os.sep, '/'), "\n"))
-                            pf.write('\t{0} {1}{2}'.format(
-                                fileList[last].replace(os.sep, '/'),
-                                "\n", "\n"))
-                        else:
-                            pf.write('{0} {1}{2}'.format(
-                                fileList[0].replace(os.sep, '/'), "\n", "\n"))
-                    
+                        pf.write(' \\\n\t'.join(
+                            [f.replace(os.sep, '/') for f in fileList]))
+                        pf.write('\n\n')
+                
                 pf.close()
                 self.__tmpProjects.append(outFile)
             except IOError:
@@ -888,7 +871,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
     def __readStderrLupdate(self):
         """
         Private slot to handle the readyReadStandardError signal of the
-        pylupdate process.
+        pylupdate4/pylupdate5/pyside-lupdate process.
         """
         proc = self.sender()
         if proc is not None:
@@ -986,8 +969,8 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         
     def __generateTSFile(self, noobsolete=False, generateAll=True):
         """
-        Private method used to run pylupdate/pylupdate4 to generate the .ts
-        files.
+        Private method used to run pylupdate4/pylupdate5/pyside-lupdate to
+        generate the .ts files.
         
         @param noobsolete flag indicating whether obsolete entries should be
             kept (boolean)
@@ -1036,23 +1019,14 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             return
         
         if self.project.getProjectType() in ["Qt4", "Qt4C"]:
-            self.pylupdate = 'pylupdate4'
-            if Utilities.isWindowsPlatform():
-                self.pylupdate = \
-                    Utilities.getWindowsExecutablePath(self.pylupdate)
+            self.pylupdate = Utilities.generatePyQtToolPath('pylupdate4')
         elif self.project.getProjectType() in ["PyQt5", "PyQt5C"]:
-            self.pylupdate = 'pylupdate5'
-            if Utilities.isWindowsPlatform():
-                self.pylupdate = \
-                    Utilities.getWindowsExecutablePath(self.pylupdate)
+            self.pylupdate = Utilities.generatePyQtToolPath('pylupdate5')
         elif self.project.getProjectType() in ["E6Plugin"]:
             if PYQT_VERSION < 0x050000:
-                self.pylupdate = 'pylupdate4'
+                self.pylupdate = Utilities.generatePyQtToolPath('pylupdate4')
             else:
-                self.pylupdate = 'pylupdate5'
-            if Utilities.isWindowsPlatform():
-                self.pylupdate = \
-                    Utilities.getWindowsExecutablePath(self.pylupdate)
+                self.pylupdate = Utilities.generatePyQtToolPath('pylupdate5')
         elif self.project.getProjectType() in ["PySide", "PySideC"]:
             self.pylupdate = Utilities.generatePySideToolPath('pyside-lupdate')
         else:
