@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,8 +9,7 @@ Module implementing a widget to show numbers in different formats.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import pyqtSlot, pyqtSignal, Qt, QAbstractTableModel, \
-    qVersion
+from PyQt5.QtCore import pyqtSlot, pyqtSignal, Qt, QAbstractTableModel
 from PyQt5.QtWidgets import QWidget, QHeaderView
 
 from E5Gui.E5Application import e5App
@@ -18,6 +17,7 @@ from E5Gui.E5Application import e5App
 from .Ui_NumbersWidget import Ui_NumbersWidget
 
 import UI.PixmapCache
+from Globals import qVersionTuple
 
 
 class BinaryModel(QAbstractTableModel):
@@ -201,7 +201,7 @@ class NumbersWidget(QWidget, Ui_NumbersWidget):
         
         self.__model = BinaryModel(self)
         self.binTable.setModel(self.__model)
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             self.binTable.horizontalHeader().setSectionResizeMode(
                 QHeaderView.ResizeToContents)
         else:
